@@ -17,10 +17,12 @@ UnixAuthorizer and WindowsAuthorizer are platform specific and
 interact with UNIX and Windows password database.
 """
 
-
 import os
 import warnings
 
+from .exceptions import AuthenticationFailed
+from .exceptions import AuthorizerError
+
 __all__ = [
     "DummyAuthorizer",
     # 'BaseUnixAuthorizer', 'UnixAuthorizer',
@@ -28,19 +30,6 @@ __all__ = [
 ]
 
 
-# ===================================================================
-# --- exceptions
-# ===================================================================
-
-
-class AuthorizerError(Exception):
-    """Base class for authorizer exceptions."""
-
-
-class AuthenticationFailed(Exception):
-    """Exception raised when authentication fails for any reason."""
-
-
 # ===================================================================
 # --- base class
 # ===================================================================
